This package is designed to simplify the tasks of 19-21 EGE in computer science, which are dedicated to game theory.

Provided two classes (Game1, Game2) for one and two heaps respectively. Class Game is abstract and parent to others.